@@ -29,7 +29,7 @@ import sys
 from .config import Var, log_message, create_dirs, VERSION, Path
 from .filters import subscribe, subscribe_custom, update_all, change_permissions, unsubscribe, rename_custom, \
     sync_filter_list_repo, show_info, FilterPermissions, list_filter_lists, search_filter_lists, purge_cache, \
-    query_domain_to_filter_list
+    query_domain_to_filter_list, init_tblock
 from .hosts import update_hosts, restore_hosts, gen_hosts, enable_protection
 from .style import show_status
 from tblock.daemon import start_daemon
@@ -140,6 +140,13 @@ def __setup_args_tblock(args: list) -> Arguments:
     )
 
     # Add "Filter lists" operations
+    parser.add_operation(
+        operation="--init",
+        short_operation="-1",
+        value_type=bool,
+        description="Setup TBlock for the first time",
+        group="Filter lists"
+    )
     parser.add_operation(
         operation="--sync",
         short_operation="-Y",
@@ -273,6 +280,14 @@ def __setup_args_tblock(args: list) -> Arguments:
         group="General",
         available_with_groups=["General", "Rules", "Filter lists", "Hosts"]
     )
+    parser.add_option(
+        option="--quiet",
+        short_option="-q",
+        value_type=bool,
+        description="Be the least verbose possible",
+        group="General",
+        available_with_groups=["General", "Rules", "Filter lists", "Hosts", "Search"]
+    )
 
     # Add "Rules" options
     parser.add_option(
@@ -497,6 +512,13 @@ def __setup_args_tblockc(args: list) -> Arguments:
         description="Block domains using \"server\" (dnsmasq)",
         available_with_operations=["--convert"]
     )
+    parser.add_option(
+        option="--quiet",
+        short_option="-q",
+        value_type=bool,
+        description="Be the least verbose possible",
+        available_with_operations=["--convert", "--get-syntax"]
+    )
 
     return parser
 
@@ -541,6 +563,13 @@ def __setup_args_tblockd(args: list) -> Arguments:
         description="Path to the config file to use",
         default_value=Path.CONFIG
     )
+    parser.add_option(
+        option="--quiet",
+        short_option="-q",
+        value_type=bool,
+        available_with_operations=["--daemon"],
+        description="Do not print output"
+    )
     parser.add_option(
         option="--no-pid",
         short_option="-n",
@@ -567,21 +596,21 @@ def __parse_args_tblock(args: list) -> None:
     if operations["--help"]:
         print(parser.help_page)
     elif operations["--status"]:
-        show_status()
+        show_status(quiet=options["--quiet"])
     elif operations["--version"]:
         print(f"TBlock v{VERSION} - An anti-capitalist ad-blocker that uses the hosts file\n\n{LICENSE_TEXT}")
     elif operations["--allow"]:
         allow_domains(
             domains=operations["--allow"],
             force=options["--force"],
-            quiet=False,
-            also_update_hosts=options["--rebuild-hosts"]
+            quiet=options["--quiet"],
+            also_update_hosts=options["--rebuild-hosts"],
         )
     elif operations["--block"]:
         block_domains(
             domains=operations["--block"],
             force=options["--force"],
-            quiet=False,
+            quiet=options["--quiet"],
             also_update_hosts=options["--rebuild-hosts"]
         )
     elif operations["--redirect"]:
@@ -589,24 +618,27 @@ def __parse_args_tblock(args: list) -> None:
             domains=operations["--redirect"],
             ip=options["--ip"],
             force=options["--force"],
-            quiet=False,
+            quiet=options["--quiet"],
             also_update_hosts=options["--rebuild-hosts"]
         )
     elif operations["--delete-rule"]:
         delete_rules(
             domains=operations["--delete-rule"],
-            quiet=False,
+            quiet=options["--quiet"],
             also_update_hosts=options["--rebuild-hosts"]
         )
+    elif operations["--init"]:
+        init_tblock()
     elif operations["--sync"]:
         sync_filter_list_repo(
-            force=options["--force"]
+            force=options["--force"],
+            quiet=options["--quiet"]
         )
     elif operations["--subscribe"]:
         subscribe(
             filter_lists=operations["--subscribe"],
             do_not_prompt=options["--no-prompt"],
-            quiet=False,
+            quiet=options["--quiet"],
             sync_repo=options["--with-sync"],
             full_update=options["--with-update"],
             permissions=FilterPermissions(options["--permissions"]),
@@ -616,7 +648,7 @@ def __parse_args_tblock(args: list) -> None:
         subscribe_custom(
             filter_lists=operations["--add-custom"],
             do_not_prompt=options["--no-prompt"],
-            quiet=False,
+            quiet=options["--quiet"],
             sync_repo=options["--with-sync"],
             full_update=options["--with-update"],
             permissions=FilterPermissions(options["--permissions"]),
@@ -627,7 +659,7 @@ def __parse_args_tblock(args: list) -> None:
         rename_custom(
             filter_lists=operations["--rename"],
             do_not_prompt=options["--no-prompt"],
-            quiet=False,
+            quiet=options["--quiet"],
             sync_repo=options["--with-sync"],
             full_update=options["--with-update"],
             force=options["--force"]
@@ -636,7 +668,7 @@ def __parse_args_tblock(args: list) -> None:
         unsubscribe(
             filter_lists=operations["--remove"],
             do_not_prompt=options["--no-prompt"],
-            quiet=False,
+            quiet=options["--quiet"],
             sync_repo=options["--with-sync"],
             full_update=options["--with-update"],
             force=options["--force"]
@@ -644,7 +676,7 @@ def __parse_args_tblock(args: list) -> None:
     elif operations["--update"]:
         update_all(
             do_not_prompt=options["--no-prompt"],
-            quiet=False,
+            quiet=options["--quiet"],
             sync_repo=options["--with-sync"],
             force=options["--force"]
         )
@@ -653,33 +685,33 @@ def __parse_args_tblock(args: list) -> None:
             filter_lists=operations["--mod"],
             permissions=FilterPermissions(options["--permissions"]),
             do_not_prompt=options["--no-prompt"],
-            quiet=False,
+            quiet=options["--quiet"],
             sync_repo=options["--with-sync"],
             force=options["--force"]
         )
     elif operations["--info"]:
         show_info(
             filter_lists=operations["--info"],
-            quiet=False
+            quiet=options["--quiet"]
         )
     elif operations["--purge-cache"]:
         purge_cache(
             do_not_prompt=options["--no-prompt"],
-            quiet=False
+            quiet=options["--quiet"]
         )
     elif operations["--disable"]:
         restore_hosts(
-            quiet=False,
+            quiet=options["--quiet"],
             do_not_prompt=options["--no-prompt"]
         )
     elif operations["--enable"]:
         enable_protection(
-            quiet=False,
+            quiet=options["--quiet"],
             do_not_prompt=options["--no-prompt"]
         )
     elif operations["--update-hosts"]:
         update_hosts(
-            quiet=False,
+            quiet=options["--quiet"],
             do_not_prompt=options["--no-prompt"]
         )
     elif operations["--gen-hosts"]:
@@ -695,7 +727,8 @@ def __parse_args_tblock(args: list) -> None:
             custom_only=options["--custom"],
             on_repo_only=options["--on-repo"],
             subscribing_only=options["--subscribing"],
-            not_subscribing_only=options["--not-subscribing"]
+            not_subscribing_only=options["--not-subscribing"],
+            quiet=options["--quiet"],
         )
     elif operations["--search"]:
         search_filter_lists(
@@ -703,10 +736,11 @@ def __parse_args_tblock(args: list) -> None:
             custom_only=options["--custom"],
             on_repo_only=options["--on-repo"],
             subscribing_only=options["--subscribing"],
-            not_subscribing_only=options["--not-subscribing"]
+            not_subscribing_only=options["--not-subscribing"],
+            quiet=options["--quiet"],
         )
     elif operations["--which"]:
-        query_domain_to_filter_list(domains=operations["--which"])
+        query_domain_to_filter_list(domains=operations["--which"], quiet=options["--quiet"])
 
 
 def __parse_args_tblockc(args: list) -> None:
@@ -725,7 +759,7 @@ def __parse_args_tblockc(args: list) -> None:
     elif operations["--version"]:
         print(f'''TBlockc v{VERSION} - TBlock's built-in filter converter\n\n{LICENSE_TEXT}''''')
     elif operations["--get-syntax"]:
-        detect_filter_list_syntax(operations["--get-syntax"])
+        detect_filter_list_syntax(operations["--get-syntax"], quiet=options["--quiet"])
     elif operations["--list-syntax"]:
         list_syntax()
     elif operations["--convert"]:
@@ -737,7 +771,8 @@ def __parse_args_tblockc(args: list) -> None:
             allow_comments=options["--comments"],
             redirect_to_zero=options["--zero"],
             dnsmasq_server=options["--server"],
-            optimize=options["--optimize"]
+            optimize=options["--optimize"],
+            quiet=options["--quiet"]
         )
 
 
@@ -753,7 +788,7 @@ def __parse_args_tblockd(args: list) -> None:
     # Parse arguments
     operations, options = parser.parse()
     if operations["--daemon"] and options["--config"]:
-        start_daemon(options["--config"], no_pid=options["--no-pid"])
+        start_daemon(options["--config"], no_pid=options["--no-pid"], quiet=options["--quiet"])
     elif operations["--help"]:
         print(parser.help_page)
     elif operations["--version"]:
