@@ -29,7 +29,7 @@ import hashlib
 # Local modules
 from .config import Path, VERSION, log_message
 from .style import Font
-from .const import RulePolicy
+from .const import RulePolicy, USER_RULE_PRIORITY
 
 
 def setup_new_database(quiet: bool = False) -> None:
@@ -81,6 +81,28 @@ def setup_new_database(quiet: bool = False) -> None:
         except sqlite3.IntegrityError:
             pass
         conn.commit()
+    with sqlite3.connect(Path.RULES_DATABASE) as conn:
+        conn.cursor().execute('''CREATE TABLE IF NOT EXISTS "r" (
+            "domain"    TEXT NOT NULL UNIQUE,
+            "policy"    TEXT NOT NULL,
+            "ip"    TEXT,
+            PRIMARY KEY("domain")
+        );''')
+
+
+def update_database_from_2_4_1(quiet: bool = False) -> None:
+    """
+    :param quiet: Optional. Do not display an output (false by default)
+    """
+    with sqlite3.connect(Path.DATABASE) as conn:
+        user_rules = conn.cursor().execute("SELECT domain, policy, ip FROM rules WHERE filter_id=?",
+                                           (USER_RULE_PRIORITY,))
+        print(f'{Font.BOLD}==> Moving user rules to second database{Font.DEFAULT}')
+        with sqlite3.connect(Path.RULES_DATABASE) as conn2:
+            cur = conn2.cursor()
+            for x in user_rules:
+                cur.execute("INSERT INTO r (domain, policy, ip) VALUES (?, ?, ?)", (x[0], x[1], x[2]))
+        conn.cursor().execute("DELETE FROM rules WHERE filter_id=?", (USER_RULE_PRIORITY,))
 
 
 def update_database_from_2_3_0(quiet: bool = False) -> None:
@@ -201,5 +223,7 @@ def init_db(quiet: bool = False) -> None:
                         conn.close()
                         if db_version < "2.4.0":
                             update_database_from_2_3_0(quiet=quiet)
+                        if db_version < "2.5.0":
+                            update_database_from_2_4_1(quiet=quiet)
             else:
                 update_database_from_1_3_2(quiet=quiet)
