@@ -32,7 +32,7 @@ import sqlite3
 from .const import FilterPermissions
 
 
-VERSION = "2.4.1"
+VERSION = "2.5.0"
 
 
 class Path:
@@ -75,6 +75,7 @@ class Path:
 
     # Define other paths
     DATABASE = os.path.join(PREFIX, 'storage.sqlite')
+    RULES_DATABASE = os.path.join(PREFIX, 'user.db')
     HOSTS_BACKUP = os.path.join(PREFIX, 'hosts.bak')
     DB_LOCK = os.path.join(PREFIX, '.db_lock')
     BUILT_HOSTS_BACKUP = os.path.join(PREFIX, 'active.hosts.bak')
@@ -91,19 +92,23 @@ class Var:
     __config = load_config(Path.CONFIG)
 
     try:
-        DEFAULT_PERMISSIONS = FilterPermissions(__config.get("default", "default_permissions"))
+        DEFAULT_PERMISSIONS = FilterPermissions(__config.get("policy", "regular"))
     except (configparser.NoSectionError, configparser.NoOptionError, ValueError):
         DEFAULT_PERMISSIONS = FilterPermissions('AB')
     try:
-        DEFAULT_IP = __config.get("default", "default_ip")
+        DEFAULT_PERMISSIONS_CUSTOM = FilterPermissions(__config.get("policy", "custom"))
+    except (configparser.NoSectionError, configparser.NoOptionError, ValueError):
+        DEFAULT_PERMISSIONS_CUSTOM = FilterPermissions('AB')
+    try:
+        DEFAULT_IP = __config.get("hosts", "default_ip")
     except (configparser.NoSectionError, configparser.NoOptionError, ValueError):
         DEFAULT_IP = "0.0.0.0"
     try:
-        DEFAULT_IPV6 = __config.get("default", "default_ipv6")
+        DEFAULT_IPV6 = __config.get("hosts", "default_ipv6")
     except (configparser.NoSectionError, configparser.NoOptionError, ValueError):
         DEFAULT_IPV6 = "::1"
     try:
-        ALLOW_IPV6 = __config.getboolean("default", "allow_ipv6")
+        ALLOW_IPV6 = __config.getboolean("hosts", "allow_ipv6")
     except (configparser.NoSectionError, configparser.NoOptionError, ValueError):
         ALLOW_IPV6 = False
     REPO_MIRRORS = [
