@@ -91,6 +91,8 @@ class FilterParser:
         percent = 0
         all_rules_count = len(data)
 
+        rules_connection = sqlite3.connect(Path.RULES_DATABASE)
+        rules_cursor = rules_connection.cursor()
         connection = sqlite3.connect(Path.DATABASE)
         cursor = connection.cursor()
 
@@ -99,6 +101,12 @@ class FilterParser:
         tblock_policy = None
         tblock_ip = None
 
+        user_rules = []
+        u = rules_cursor.execute('SELECT "domain" FROM "r" ORDER BY domain ASC;').fetchall()
+        for x in u:
+            user_rules.append(u[0])
+        rules_connection.close()
+
         for line in data:
 
             count += 1
@@ -143,24 +151,25 @@ class FilterParser:
                     policy = rule[1]
 
                     # Check whether the rule already exists in the database
-                    query = cursor.execute("SELECT domain, filter_id, policy FROM rules WHERE domain=?",
-                                           (rule[0],)).fetchall()
+                    if domain not in user_rules:
+                        query = cursor.execute("SELECT domain, policy FROM rules WHERE domain=?",
+                                               (domain,)).fetchone()
 
-                    # Check if the rule exists and if the rule is not a user rule
-                    if query and query[0][1] != USER_RULE_PRIORITY:
-                        # Check if the local rule has a higher priority (block < redirect < allow)
-                        if query[0][2] == policy == RulePolicy.BLOCK or \
-                                policy == RulePolicy.REDIRECT and policy != RulePolicy.ALLOW or \
-                                policy == RulePolicy.ALLOW:
+                        # Check if the rule exists and if the rule is not a user rule
+                        if query:
+                            # Check if the local rule has a higher priority (block < redirect < allow)
+                            if query[1] == policy == RulePolicy.BLOCK or \
+                                    policy == RulePolicy.REDIRECT and policy != RulePolicy.ALLOW or \
+                                    policy == RulePolicy.ALLOW:
+                                cursor.execute(
+                                    "UPDATE rules SET policy=?, filter_id=?, ip=? WHERE domain=?;",
+                                    (policy, filter_id, ip, domain)
+                                )
+                        else:
                             cursor.execute(
-                                "UPDATE rules SET policy=?, filter_id=?, ip=? WHERE domain=?;",
-                                (policy, filter_id, ip, domain)
+                                "INSERT INTO rules (domain, policy, filter_id, ip) VALUES (?, ?, ?, ?);",
+                                (domain, policy, filter_id, ip)
                             )
-                    elif not query:
-                        cursor.execute(
-                            "INSERT INTO rules (domain, policy, filter_id, ip) VALUES (?, ?, ?, ?);",
-                            (domain, policy, filter_id, ip)
-                        )
 
         if not self.quiet:
             print(" {0} Inserting rules into database ({1}): {2}%".format(Icon.SUCCESS, all_rules_count, percent))
@@ -340,10 +349,14 @@ def convert(input_file: str, output_file: str, output_syntax: str, input_syntax:
                           redirect_to_zero=redirect_to_zero, dnsmasq_server=dnsmasq_server, optimize=optimize)
 
 
-def detect_filter_list_syntax(input_file: str) -> None:
-    print(f"{Font.BOLD}==> Detecting filter list syntax{Font.DEFAULT}")
-    filter_parser = FilterParser(input_file)
-    print(f" {Icon.INFORMATION} Filter list syntax is: {filter_parser.syntax}")
+def detect_filter_list_syntax(input_file: str, quiet: bool = False) -> None:
+    if not quiet:
+        print(f"{Font.BOLD}==> Detecting filter list syntax{Font.DEFAULT}")
+    filter_parser = FilterParser(input_file, quiet=quiet)
+    if not quiet:
+        print(f" {Icon.INFORMATION} Filter list syntax is: {filter_parser.syntax}")
+    else:
+        print(filter_parser.syntax)
 
 
 def list_syntax() -> None:
