@@ -137,10 +137,17 @@ def update_hosts(quiet: bool = False, do_not_prompt: bool = True) -> None:
 
         # Update temporary file to avoid causing damage to hosts
         with open(os.path.join(Path.TMP_DIR, "hosts.txt"), "wt") as w:
-            db = sqlite3.connect(Path.DATABASE)
+            db = sqlite3.connect(Path.RULES_DATABASE)
             cursor = db.cursor()
-            total_rules = cursor.execute('SELECT COUNT() FROM rules;').fetchone()[0]
+            total_rules = cursor.execute('SELECT COUNT() FROM r;').fetchone()[0]
             rules = cursor.execute(
+                "SELECT domain, policy, ip FROM r WHERE policy != ? ORDER BY domain ASC;", (RulePolicy.ALLOW,)
+            )
+
+            db2 = sqlite3.connect(Path.DATABASE)
+            cursor2 = db2.cursor()
+            total_rules += cursor2.execute('SELECT COUNT() FROM rules;').fetchone()[0]
+            rules2 = cursor2.execute(
                 "SELECT domain, policy, ip FROM rules WHERE policy != ? ORDER BY domain ASC;", (RulePolicy.ALLOW,)
             )
             count = 0
@@ -148,7 +155,7 @@ def update_hosts(quiet: bool = False, do_not_prompt: bool = True) -> None:
             __msg = "Retrieving rules:"
             w.write(f"# This file is generated by TBlock\n"
                     f"# Do not edit it manually, otherwise your changes will be overwritten"
-                    f"\n\n# ----- DEFAULT HOSTS -----\n{default_hosts}\n\n# ----- TBLOCK RULES -----\n"
+                    f"\n\n# ----- DEFAULT HOSTS -----\n{default_hosts}\n\n# ----- CUSTOM RULES -----\n"
                     )
         with open(os.path.join(Path.TMP_DIR, "hosts.txt"), "at") as w:
             content = ""
@@ -161,12 +168,32 @@ def update_hosts(quiet: bool = False, do_not_prompt: bool = True) -> None:
                     if row[1] == RulePolicy.BLOCK:
                         content += f"{Var.DEFAULT_IP}\t\t{row[0]}\n"
                         if Var.ALLOW_IPV6:
-                            w.write(f"{Var.DEFAULT_IPV6}\t\t\t{row[0]}\n")
+                            content += f"{Var.DEFAULT_IPV6}\t\t\t{row[0]}\n"
                     elif row[1] == RulePolicy.REDIRECT:
                         content += f"{row[2]}\t\t{row[0]}\n"
                 if count % 100000 == 0:
                     w.write(content)
                     content = ""
+            content += "\n\n# ----- TBLOCK RULES -----\n"
+            db.close()
+            w.write(content)
+            content = ""
+            for row in rules2:
+                count += 1
+                percent = int(count * 100 / total_rules)
+                if not quiet:
+                    print(f" {loading_icon(count)} {__msg} {count}/{total_rules} ({percent}%)", end="\r")
+                if not invalid:
+                    if row[1] == RulePolicy.BLOCK:
+                        content += f"{Var.DEFAULT_IP}\t\t{row[0]}\n"
+                        if Var.ALLOW_IPV6:
+                            content += f"{Var.DEFAULT_IPV6}\t\t\t{row[0]}\n"
+                    elif row[1] == RulePolicy.REDIRECT:
+                        content += f"{row[2]}\t\t{row[0]}\n"
+                if count % 100000 == 0:
+                    w.write(content)
+                    content = ""
+            db2.close()
             w.write(content)
         if not quiet:
             print(f" {Icon.SUCCESS} {__msg} {total_rules}/{total_rules} (100%)")
