@@ -26,6 +26,7 @@ import hashlib
 
 import requests
 import urllib3
+import urllib3.exceptions
 import ipaddress
 import socket
 
@@ -137,35 +138,20 @@ def get_readable_size(bytes_length: float) -> str:
     :param bytes_length: The file size (in Bytes)
     :return: A human-readable format of the file size
     """
-    for unity in ['B', 'KB', 'MB', 'GB', 'TB']:
+    for unity in ['B', 'KiB', 'MiB', 'GiB', 'TiB']:
         if bytes_length < 1024.0:
             return f"{round(bytes_length,1)} {unity}"
         else:
             bytes_length /= 1024.0
 
 
-def has_internet_connection(url: str) -> bool:
-    if urllib3.get_host(url)[1] == "0.0.0.0":
-        return True
-    try:
-        host = socket.gethostbyname(urllib3.get_host(url)[1])
-        if urllib3.get_host(url)[0] == "https":
-            s = socket.create_connection((host, 443), 2)
-        else:
-            s = socket.create_connection((host, 80), 2)
-        s.close()
-        return True
-    except (socket.gaierror, OSError):
-        return False
-
-
 def is_url(string: str) -> bool:
     """
     Check if a string is a valid web URL
     :param string: The string to check
     :return: True if string is a valid URL
     """
-    return bool(re.match(r'(http|ftp)(s|)://', string))
+    return bool(re.match(r'(http(s|)|(s|)ftp)://', string))
 
 
 def fetch_file(location: str, description: str, output_file: str, quiet: bool = False, sha512sum: str = None) -> bool:
@@ -183,60 +169,60 @@ def fetch_file(location: str, description: str, output_file: str, quiet: bool =
     }
     __msg = "Fetching {0}".format(description)
     if is_url(location):
-        if has_internet_connection(location):
-            # File is online and needs to be downloaded
-            try:
-                response = requests.get(location, stream=True, headers=headers)
-                if response.status_code != 200:
-                    raise TBlockNetworkError("status code is not 200")
-                online_size = int(response.headers.get('content-length', 0))
-                online_size_readable = get_readable_size(online_size)
+        # File is online and needs to be downloaded
+        try:
+            response = requests.get(location, stream=True, headers=headers, timeout=8)
+            if response.status_code != 200:
+                raise TBlockNetworkError("status code is not 200")
+            online_size = int(response.headers.get('content-length', 0))
+            online_size_readable = get_readable_size(online_size)
 
-                local_size = 0
-                count = 0
+            local_size = 0
+            count = 0
 
-                with open(output_file, 'wb') as f:
-                    for data in response.iter_content(1024):
-                        count += 1
-                        local_size += 1024
-                        if online_size != 0:
-                            percent = int(local_size * 100 / online_size)
-                        else:
-                            percent = '- '
-                        if not quiet:
-                            print(f" {loading_icon(count)} {__msg} ({online_size_readable}): {percent}%",
-                                  end="\r")
-                        f.write(data)
-
-                local_size += 1024
-                if not quiet:
-                    print(f" {Icon.SUCCESS} {__msg} ({get_readable_size(local_size)}): 100%")
-                if sha512sum is not None:
-                    if not quiet:
-                        print(f" {loading_icon(1)} Checking hash", end='\r')
-                    with open(output_file, 'rb') as r:
-                        hash = hashlib.sha512(r.read()).hexdigest()
-                    if hash == sha512sum:
-                        if not quiet:
-                            print(f" {Icon.SUCCESS} Checking hash")
-                        return True
+            with open(output_file, 'wb') as f:
+                for data in response.iter_content(1024):
+                    count += 1
+                    local_size += 1024
+                    if online_size != 0:
+                        percent = int(local_size * 100 / online_size)
                     else:
-                        if not quiet:
-                            print(f" {Icon.ERROR} Checking hash")
-                        return False
-                else:
-                    return True
+                        percent = '- '
+                    if not quiet:
+                        print(f" {loading_icon(count)} {__msg} ({online_size_readable}): {percent}%",
+                              end="\r")
+                    f.write(data)
 
-            except (requests.exceptions.ConnectionError, urllib3.exceptions.MaxRetryError, ConnectionRefusedError,
-                    urllib3.exceptions.NewConnectionError, TBlockNetworkError):
+            with open(output_file, "rb") as f:
+                local_size = len(f.read())
+            if not quiet:
+                print(f" {Icon.SUCCESS} {__msg} ({get_readable_size(local_size)}): 100%")
+            if sha512sum is not None:
+                if not quiet:
+                    print(f" {loading_icon(1)} Checking hash", end='\r')
+                with open(output_file, 'rb') as r:
+                    hash = hashlib.sha512(r.read()).hexdigest()
+                if hash == sha512sum:
+                    if not quiet:
+                        print(f" {Icon.SUCCESS} Checking hash")
+                    return True
+                else:
+                    if not quiet:
+                        print(f" {Icon.ERROR} Checking hash")
+                    return False
+            else:
+                return True
+
+        except (requests.exceptions.ConnectionError, urllib3.exceptions.MaxRetryError, ConnectionRefusedError,
+                urllib3.exceptions.NewConnectionError, TBlockNetworkError, requests.exceptions.ReadTimeout):
+            if not quiet:
                 print(f" {Icon.ERROR} {__msg} (0 B): 0%")
-                return False
-        else:
             return False
     else:
         try:
             # File is local and needs to be copied
-            online_size = os.stat(location).st_size
+            with open(location, "rb") as f:
+                online_size = len(f.read())
             online_size_readable = get_readable_size(online_size)
             if not quiet:
                 print(f" {loading_icon(1)} {__msg} ({online_size_readable}): 0%", end="\r")
@@ -259,7 +245,8 @@ def fetch_file(location: str, description: str, output_file: str, quiet: bool =
             else:
                 return True
         except (FileNotFoundError, IsADirectoryError, PermissionError):
-            print(f" {Icon.ERROR} {__msg} (0 B): 0%")
+            if not quiet:
+                print(f" {Icon.ERROR} {__msg} (0 B): 0%")
             return False
 
 
@@ -272,7 +259,11 @@ def check_root_access() -> bool:
     try:
         with open(Path.HOSTS, "at") as t:
             t.close()
-    except PermissionError:
+    except (OSError, PermissionError):
         return False
     else:
         return True
+
+
+def get_db_size() -> int:
+    return os.path.getsize(Path.DATABASE)
